@@ -65,14 +65,13 @@ mod tests {
 
     pub fn create_aggregator(current_round: RoundResult, last_round: RoundResult) -> AggregatorState {
         AggregatorState {
-            version: 1,
+            version: Some(1),
             configs: Some(mod_AggregatorState::Configs {
-                min_confirmations: 10,
-                min_update_delay_seconds: 10,
-                min_round_agreement_percentage: 0,
-                locked: false,
+                min_confirmations: Some(10),
+                min_update_delay_seconds: Some(10),
+                locked: Some(false),
             }),
-            fulfillment_manager_pubkey: Vec::new(),
+            fulfillment_manager_pubkey: Some(Vec::new()),
             job_definition_pubkeys: Vec::new(),
             agreement: None,
             current_round_result: Some(current_round),
@@ -83,22 +82,24 @@ mod tests {
     #[test]
     fn test_reject_current_on_sucess_count() {
         let current_round = RoundResult {
-            num_success: 2,
-            num_error: 5,
-            mean: 97.0,
-            round_open_slot: 1,
-            round_open_timestamp: 1,
-            min_response: 96.0,
-            max_response: 100.0
+            num_success: Some(2),
+            num_error: Some(5),
+            result: Some(97.0),
+            round_open_slot: Some(1),
+            round_open_timestamp: Some(1),
+            min_response: Some(96.0),
+            max_response: Some(100.0),
+            medians: Vec::new(),
         };
         let last_round = RoundResult {
-            num_success: 30,
-            num_error: 0,
-            mean: 100.0,
-            round_open_slot: 1,
-            round_open_timestamp: 1,
-            min_response: 100.0,
-            max_response: 100.0
+            num_success: Some(30),
+            num_error: Some(0),
+            result: Some(100.0),
+            round_open_slot: Some(1),
+            round_open_timestamp: Some(1),
+            min_response: Some(100.0),
+            max_response: Some(100.0),
+            medians: Vec::new(),
         };
         let aggregator = create_aggregator(current_round.clone(), last_round.clone());
         assert_eq!(get_aggregator_result(&aggregator).unwrap(), last_round.clone());
@@ -107,22 +108,24 @@ mod tests {
     #[test]
     fn test_accept_current_on_sucess_count() {
         let current_round = RoundResult {
-            num_success: 20,
-            num_error: 5,
-            mean: 97.0,
-            round_open_slot: 1,
-            round_open_timestamp: 1,
-            min_response: 96.0,
-            max_response: 100.0
+            num_success: Some(20),
+            num_error: Some(5),
+            result: Some(97.0),
+            round_open_slot: Some(1),
+            round_open_timestamp: Some(1),
+            min_response: Some(96.0),
+            max_response: Some(100.0),
+            medians: Vec::new(),
         };
         let last_round = RoundResult {
-            num_success: 30,
-            num_error: 0,
-            mean: 100.0,
-            round_open_slot: 1,
-            round_open_timestamp: 1,
-            min_response: 100.0,
-            max_response: 100.0
+            num_success: Some(30),
+            num_error: Some(0),
+            result: Some(100.0),
+            round_open_slot: Some(1),
+            round_open_timestamp: Some(1),
+            min_response: Some(100.0),
+            max_response: Some(100.0),
+            medians: Vec::new(),
         };
         let aggregator = create_aggregator(current_round.clone(), last_round.clone());
         assert_eq!(get_aggregator_result(&aggregator).unwrap(), current_round.clone());
